import os
from PIL import Image
import random

def random_color():
    """ Generate a random color. """
    return (random.randint(0, 255), random.randint(0, 255), random.randint(0, 255))

def process_image(image_path):
    """ Process a single image. """
    image = Image.open(image_path)
    if image.mode != 'RGBA':
        image = image.convert('RGBA')
    
    data = image.getdata()
    new_data = []
    new_color = random_color()  # Generate one random color for the image
    
    for item in data:
        if item[3] == 0:  # Preserve transparency
            new_data.append(item)
        else:
            new_data.append(new_color + (item[3],))  # Apply the random color

    image.putdata(new_data)
    image.save(image_path)  # Overwrite the original image
    print(f"Processed {image_path}")

def process_images(directory):
    """ Process each PNG image in the directory and subdirectories. """
    for root, dirs, files in os.walk(directory):
        for filename in files:
            if filename.endswith(".png"):
                path = os.path.join(root, filename)
                process_image(path)

# Specify the directory path here
directory_path = '.'
process_images(directory_path)
